@@ -219,6 +219,22 @@ class TemporalUnit(metaclass=TemporalMeta):
         self._bpm = new_bpm
         self._events = None
 
+    def make_rest(self, node: int) -> None:
+        """
+        Make a node and all its descendants into rests by setting their proportions to negative.
+        
+        This method calls the RhythmTree's make_rest method and then re-evaluates the
+        TemporalUnit to update the timing information.
+        
+        Args:
+            node: The node ID to make into a rest along with all its descendants
+            
+        Raises:
+            ValueError: If the node is not found in the rhythm tree
+        """
+        self._rt.make_rest(node)
+        self._events = None
+
     def _set_rt(self, span:int, tempus:Union[Meas,Fraction,str], prolatio:Union[tuple,str]) -> RhythmTree:
         match prolatio:
             case tuple():
@@ -459,6 +475,17 @@ class TemporalUnitSequence(metaclass=TemporalMeta):
         
         self._seq[index] = ut.copy()
         self._set_offsets()
+        
+    def extend(self, other_seq: 'TemporalUnitSequence') -> None:
+        """
+        Extend the sequence by appending all TemporalUnits from another sequence.
+        
+        Args:
+            other_seq: The TemporalUnitSequence to extend from
+        """
+        for ut in other_seq:
+            self._seq.append(ut.copy())
+        self._set_offsets()
 
     def __getitem__(self, idx: int) -> TemporalUnit:
         return self._seq[idx]
@@ -732,6 +759,17 @@ class TemporalBlock(metaclass=TemporalMeta):
         
         self._rows[index] = row.copy()
         self._align_rows()
+        
+    def extend(self, other_block: 'TemporalBlock') -> None:
+        """
+        Extend the block by appending all rows from another block.
+        
+        Args:
+            other_block: The TemporalBlock to extend from
+        """
+        for row in other_block:
+            self._rows.append(row.copy())
+        self._align_rows()
 
     def __getitem__(self, idx: int) -> Union[TemporalUnit, TemporalUnitSequence, 'TemporalBlock']:
         return self._rows[idx]
